@@ -1,8 +1,13 @@
+import time
+
 from jet_bridge_base.settings import set_settings
 
 
 class Configuration(object):
 
+    def __init__(self):
+        self.init_time = time.time()
+
     def get_type(self):
         pass
 
