@@ -69,9 +69,11 @@ FILTER_FOR_DBFIELD = {
     sqltypes.BigInteger: {'filter_class': IntegerFilter, 'lookups': number_lookups},
     sqltypes.Numeric: {'filter_class': IntegerFilter, 'lookups': number_lookups},
     sqltypes.Float: {'filter_class': IntegerFilter, 'lookups': number_lookups},
+    sqltypes.Date: {'filter_class': DateTimeFilter, 'lookups': datetime_lookups},
     sqltypes.DateTime: {'filter_class': DateTimeFilter, 'lookups': datetime_lookups},
     sqltypes.TIMESTAMP: {'filter_class': DateTimeFilter, 'lookups': datetime_lookups},
     sqltypes.JSON: {'filter_class': CharFilter, 'lookups': json_lookups},
+    sqltypes.ARRAY: {'filter_class': CharFilter, 'lookups': json_lookups},
     # sqlalchemy.TextField:                   {'filter_class': CharFilter},
     # sqlalchemy.BOOLEAN:                {'filter_class': BooleanFilter},
     # sqlalchemy.DateField:                   {'filter_class': DateFilter},
@@ -104,7 +106,7 @@ except ImportError:
 
 
 def filter_for_data_type(value):
-    for date_type, filter_data in FILTER_FOR_DBFIELD.items():
-        if isinstance(value, date_type):
+    for data_type, filter_data in FILTER_FOR_DBFIELD.items():
+        if isinstance(value, data_type):
             return filter_data
     return FILTER_FOR_DBFIELD_DEFAULT
