@@ -2,8 +2,8 @@
 class Pagination(object):
     count = None
 
-    def paginate_queryset(self, queryset, handler):
+    def paginate_queryset(self, request, queryset, handler):
         raise NotImplementedError
 
-    def get_paginated_response(self, data):
+    def get_paginated_response(self, request, data):
         raise NotImplementedError
