@@ -11,6 +11,9 @@ class ModelDescriptionFieldSerializer(Serializer):
     null = fields_.BooleanField()
     editable = fields_.BooleanField()
     params = fields_.JSONField()
+    data_source_field = fields_.CharField(required=False)
+    data_source_name = fields_.CharField(required=False)
+    data_source_params = fields_.JSONField(required=False)
     verbose_name = fields_.CharField(required=False)
     required = fields_.BooleanField(required=False)
     default_type = fields_.CharField(required=False)
@@ -33,9 +36,13 @@ class ModelDescriptionSerializer(Serializer):
     db_table = fields_.CharField()
     hidden = fields_.BooleanField()
     primary_key_field = fields_.CharField()
+    primary_key_auto = fields_.BooleanField()
     fields = ModelDescriptionFieldSerializer(many=True)
     relations = ModelDescriptionRelationSerializer(many=True)
+    relation_overrides = ModelDescriptionRelationSerializer(many=True, required=False)
     verbose_name = fields_.CharField(required=False)
     verbose_name_plural = fields_.CharField(required=False)
     display_field = fields_.CharField(required=False)
     default_order_by = fields_.CharField(required=False)
+    data_source_name = fields_.CharField(required=False)
+    data_source_name_plural = fields_.CharField(required=False)
