@@ -69,8 +69,14 @@ class ModelViewSet(ModelAPIViewMixin):
 
     def get_queryset(self, request):
         Model = self.get_model(request)
+        queryset = request.session.query(Model)
 
-        return request.session.query(Model)
+        mapper = inspect(Model)
+        auto_pk = getattr(mapper.tables[0], '__jet_auto_pk__', False) if len(mapper.tables) else None
+        if auto_pk:
+            queryset = queryset.filter(mapper.primary_key[0].isnot(None))
+
+        return queryset
 
     def filter_queryset(self, request, queryset):
         queryset = super(ModelViewSet, self).filter_queryset(request, queryset)
@@ -84,6 +90,8 @@ class ModelViewSet(ModelAPIViewMixin):
         if not isinstance(request.data, list):
             return JSONResponse({'error': 'Request body should be an array'}, status=status.HTTP_400_BAD_REQUEST)
 
+        self.apply_timezone(request)
+
         result = []
 
         for item in request.data:
@@ -102,6 +110,7 @@ class ModelViewSet(ModelAPIViewMixin):
 
     @action(methods=['get'], detail=False)
     def aggregate(self, request, *args, **kwargs):
+        self.apply_timezone(request)
         queryset = self.filter_queryset(request, self.get_queryset(request))
 
         y_func = request.get_argument('_y_func').lower()
@@ -132,6 +141,7 @@ class ModelViewSet(ModelAPIViewMixin):
 
     @action(methods=['get'], detail=False)
     def group(self, request, *args, **kwargs):
+        self.apply_timezone(request)
         queryset = self.filter_queryset(request, self.get_queryset(request))
 
         x_columns = request.get_arguments('_x_column')
@@ -175,6 +185,7 @@ class ModelViewSet(ModelAPIViewMixin):
 
     @action(methods=['post'], detail=False)
     def reorder(self, request, *args, **kwargs):
+        self.apply_timezone(request)
         queryset = self.filter_queryset(request, self.get_queryset(request))
         Model = self.get_model(request)
         ReorderSerializer = get_reorder_serializer(Model, queryset, request.session)
@@ -187,6 +198,7 @@ class ModelViewSet(ModelAPIViewMixin):
 
     @action(methods=['post'], detail=False)
     def reset_order(self, request, *args, **kwargs):
+        self.apply_timezone(request)
         queryset = self.filter_queryset(request, self.get_queryset(request))
         Model = self.get_model(request)
         ResetOrderSerializer = get_reset_order_serializer(Model, queryset, request.session)
@@ -199,6 +211,7 @@ class ModelViewSet(ModelAPIViewMixin):
 
     @action(methods=['get'], detail=True)
     def get_siblings(self, request, *args, **kwargs):
+        self.apply_timezone(request)
         queryset = self.filter_queryset(request, self.get_queryset(request))
         obj = self.get_object(request)
         Model = self.get_model(request)
