@@ -1,10 +1,14 @@
+import json
 import re
 
+from jet_bridge_base.models.model_relation_override import ModelRelationOverrideModel
+from jet_bridge_base.store import store
+from jet_bridge_base.utils.relations import relationship_direction_to_str
 from sqlalchemy import inspect, String, Enum, Date
-from sqlalchemy.orm import ONETOMANY
+from sqlalchemy.orm import MANYTOONE, ONETOMANY
 from sqlalchemy.sql.elements import TextClause
 
-from jet_bridge_base.db import get_mapped_base
+from jet_bridge_base.db import get_mapped_base, get_request_connection
 from jet_bridge_base.models import data_types
 from jet_bridge_base.permissions import HasProjectPermissions
 from jet_bridge_base.responses.json import JSONResponse
@@ -60,6 +64,9 @@ def map_column_default(column):
 
 def map_column(column, editable):
     params = {}
+    data_source_field = None
+    data_source_name = None
+    data_source_params = None
 
     try:
         map_type = sql_to_map_type(column.type)
@@ -96,6 +103,26 @@ def map_column(column, editable):
 
     optional = is_column_optional(column)
 
+    if column.comment:
+        try:
+            data_source_meta = json.loads(column.comment)
+
+            if not isinstance(data_source_meta, dict):
+                raise ValueError
+
+            meta_field = data_source_meta.get('field')
+            meta_name = data_source_meta.get('name')
+            meta_params = data_source_meta.get('params')
+
+            if meta_field is not None:
+                data_source_field = meta_field
+            if meta_name is not None:
+                data_source_name = meta_name
+            if meta_params is not None and isinstance(meta_params, dict):
+                data_source_params = meta_params
+        except ValueError:
+            pass
+
     result = {
         'name': column.name,
         'db_column': column.name,
@@ -105,7 +132,10 @@ def map_column(column, editable):
         'required': not optional,
         'null': column.nullable,
         'editable': editable,
-        'params': params
+        'params': params,
+        'data_source_field': data_source_field,
+        'data_source_name': data_source_name,
+        'data_source_params': data_source_params
     }
 
     server_default = map_column_default(column)
@@ -120,10 +150,11 @@ def map_column(column, editable):
 def map_relationship(relationship):
     local_field = get_set_first(relationship.local_columns)
     related_field = get_set_first(relationship.remote_side)
+    direction = relationship_direction_to_str(relationship.direction)
 
     result = {
         'name': relationship.key,
-        'direction': 'ONETOMANY',
+        'direction': direction,
         'local_field': local_field.name,
         'related_model': relationship.target.name,
         'related_field': related_field.name
@@ -132,6 +163,18 @@ def map_relationship(relationship):
     return result
 
 
+def map_relationship_override(override):
+    result = {
+        'name': override.name,
+        'direction': override.direction,
+        'local_field': override.local_field,
+        'related_model': override.related_model,
+        'related_field': override.related_field
+    }
+
+    return result
+
+
 # def map_relation(relation):
 #     field = None
 #
@@ -184,23 +227,50 @@ def map_relationship(relationship):
 #
 #     return result
 
-def map_table(cls, hidden):
+def map_table(cls, relationships_overrides, hidden):
     mapper = inspect(cls)
+    table = mapper.tables[0]
     name = mapper.selectable.name
     primary_key = mapper.primary_key[0]
+    primary_key_auto = getattr(table, '__jet_auto_pk__', False) if table is not None else None
     non_editable = []
+    model_relationships_overrides = relationships_overrides.get(name)
 
     from jet_bridge_base.configuration import configuration
     additional = configuration.get_model_description(name)
 
+    data_source_name = None
+    data_source_name_plural = None
+
+    if table.comment:
+        try:
+            data_source_meta = json.loads(table.comment)
+
+            if not isinstance(data_source_meta, dict):
+                raise ValueError
+
+            meta_name = data_source_meta.get('name')
+            meta_name_plural = data_source_meta.get('name_plural')
+
+            if meta_name is not None:
+                data_source_name = meta_name
+            if meta_name_plural is not None:
+                data_source_name_plural = meta_name_plural
+        except ValueError:
+            pass
+
     result = {
         'model': name,
         'db_table': name,
         'fields': list(map(lambda x: map_column(x, x.name not in non_editable), mapper.columns)),
-        'relations': list(map(lambda x: map_relationship(x), filter(lambda x: x.direction == ONETOMANY, mapper.relationships))),
+        'relations': list(map(lambda x: map_relationship(x), filter(lambda x: x.direction in [MANYTOONE, ONETOMANY], mapper.relationships))),
+        'relation_overrides': list(map(lambda x: map_relationship_override(x), model_relationships_overrides)) if model_relationships_overrides else None,
         'hidden': name in hidden or name in configuration.get_hidden_model_description(),
         # 'relations': table_relations(mapper) + table_m2m_relations(mapper),
-        'primary_key_field': primary_key.name if primary_key is not None else None
+        'primary_key_field': primary_key.name if primary_key is not None else None,
+        'primary_key_auto': primary_key_auto,
+        'data_source_name': data_source_name,
+        'data_source_name_plural': data_source_name_plural
     }
 
     if additional:
@@ -216,8 +286,24 @@ class ModelDescriptionView(APIView):
     def get_queryset(self, request):
         hidden = ['__jet__token']
         MappedBase = get_mapped_base(request)
+        relationships_overrides = {}
+        draft = bool(request.get_argument('draft', False))
 
-        return list(map(lambda x: map_table(x, hidden), MappedBase.classes))
+        if store.is_ok():
+            connection = get_request_connection(request)
+
+            with store.session() as session:
+                overrides = session.query(ModelRelationOverrideModel).filter(
+                    ModelRelationOverrideModel.connection_id == connection['id'],
+                    draft == draft
+                ).all()
+
+                for override in overrides:
+                    if override.model not in relationships_overrides:
+                        relationships_overrides[override.model] = []
+                    relationships_overrides[override.model].append(override)
+
+        return list(map(lambda x: map_table(x, relationships_overrides, hidden), MappedBase.classes))
 
     def get(self, request, *args, **kwargs):
         queryset = self.get_queryset(request)
