@@ -1,4 +1,4 @@
-from jet_bridge_base.db import dispose_connection, get_request_connection
+from jet_bridge_base.db import dispose_request_connection, get_request_connection
 from jet_bridge_base.permissions import HasProjectPermissions
 from jet_bridge_base.responses.json import JSONResponse
 from jet_bridge_base.views.base.api import APIView
@@ -15,7 +15,7 @@ class ReloadView(APIView):
         }
 
     def post(self, request, *args, **kwargs):
-        result = dispose_connection(request)
+        result = dispose_request_connection(request)
         get_request_connection(request)
         return JSONResponse({
             'success': result
