@@ -3,6 +3,7 @@ from jet_bridge_base.exceptions.validation_error import ValidationError
 from jet_bridge_base.permissions import HasProjectPermissions
 from jet_bridge_base.responses.json import JSONResponse
 from jet_bridge_base.serializers.sql import SqlSerializer, SqlsSerializer
+from jet_bridge_base.utils.track_database import track_database_async
 from jet_bridge_base.views.base.api import APIView
 from jet_bridge_base.status import HTTP_400_BAD_REQUEST
 
@@ -11,6 +12,8 @@ class SqlView(APIView):
     permission_classes = (HasProjectPermissions,)
 
     def post(self, request, *args, **kwargs):
+        track_database_async(request)
+
         if 'queries' in request.data:
             serializer = SqlsSerializer(data=request.data, context={'request': request})
         else:
